@@ -2,11 +2,11 @@ from __future__ import absolute_import
 #from hedaro.core.main import (
 #Targets
 #)
-from hedaro.core.main import get_amass 
+from hedaro.core.main import KaliAccessor 
 
 """hedaro - A pentesting library for Python"""
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 __author__ = 'David Rojas <david@hedaro.com>'
 __all__ = []
 
